@@ -30,7 +30,7 @@ static char rcsid[]
 #	ifdef __GNUC__
 		__attribute__ ((unused))
 #	endif
-	= "$Id: util.c 30 2012-11-13 22:35:58Z mmamonski $";
+	= "$Id: util.c 34 2013-12-02 09:44:05Z mmamonski $";
 #endif
 
 unsigned int
@@ -238,8 +238,8 @@ slurmdrmaa_add_attribute(job_desc_msg_t *job_desc, unsigned attr, const char *va
 			}
 		#else
 			if(job_desc->pn_min_memory == NO_VAL ||  fsd_atoi(value) > (int)job_desc->pn_min_memory) {
-				fsd_log_debug(("# pn_min_memory = %s",value));
-				job_desc->pn_min_memory = fsd_atoi(value);
+				fsd_log_debug(("# pn_min_memory (MEM_PER_CPU) = %s",value));
+				job_desc->pn_min_memory = fsd_atoi(value) | MEM_PER_CPU;
 			}
 		#endif
 			else { 
@@ -352,7 +352,6 @@ slurmdrmaa_add_attribute(job_desc_msg_t *job_desc, unsigned attr, const char *va
             		job_desc->job_min_tmp_disk = fsd_atoi(value);
             		#endif
 			break;
-	
 		default:
 			fsd_exc_raise_fmt(FSD_DRMAA_ERRNO_INVALID_ATTRIBUTE_VALUE,"Invalid attribute");
 	}
@@ -532,6 +531,9 @@ slurmdrmaa_parse_native(job_desc_msg_t *job_desc, const char * value)
 					case 'x' :
 						slurmdrmaa_add_attribute(job_desc,SLURM_NATIVE_EXCLUDE, arg);
 						break;
+					case 'L' :
+						slurmdrmaa_add_attribute(job_desc,SLURM_NATIVE_LICENSES, arg);
+						break;							
 					default :
 							fsd_exc_raise_fmt(FSD_DRMAA_ERRNO_INVALID_ATTRIBUTE_VALUE,
 									"Invalid native specification: %s (Unsupported option: -%c)",
